@@ -12,11 +12,11 @@ import maitai
 from maitai._config import config
 from maitai._evaluator import Evaluator
 from maitai._inference import InferenceException, InferenceWarning
-from maitai._types import Body, Headers, Query
+from maitai._types import Body, Headers, MaitaiChunk, MaitaiCompletion, Query
 from maitai._utils import convert_open_ai_chat_completion_chunk, convert_openai_chat_completion, get_chat_completion_params, required_args
 from maitai_common.utils.proto_utils import openai_messages_to_proto
 from maitai_common.utils.types import EvaluateCallback
-from maitai_gen.chat import ChatCompletionChunk, ChatCompletionParams, ChatCompletionResponse, ChatMessage, EvaluationContentType
+from maitai_gen.chat import ChatCompletionParams, ChatMessage, EvaluationContentType
 from maitai_gen.config import InferenceLocations
 from maitai_gen.inference import InferenceStreamResponse
 
@@ -132,7 +132,7 @@ class Completions:
         extra_query: Optional[Query] = None,
         extra_body: Optional[Body] = None,
         timeout: Union[float, httpx.Timeout, None, openai.NotGiven] = openai.NOT_GIVEN,
-    ) -> Union[ChatCompletionResponse, Iterable[ChatCompletionChunk]]:
+    ) -> Union[MaitaiCompletion, Iterable[MaitaiChunk]]:
         if not config.api_key:
             raise ValueError("Maitai API Key has not been set")
         if server_side_inference is False and apply_corrections is True:
@@ -204,13 +204,13 @@ class Completions:
             if stream:
                 return _process_inference_stream(response)
             # ChatCompletion only
-            chat_completion: Optional[ChatCompletionResponse] = None
+            chat_completion: Optional[MaitaiCompletion] = None
             for resp in response:
                 if resp.warning:
                     warnings.warn(resp.warning, InferenceWarning)
                 if resp.error:
                     raise InferenceException(resp.error)
-                return resp.chat_completion_response
+                return MaitaiCompletion(resp.chat_completion_response)
             return chat_completion
         else:
             if self.client is None:
@@ -273,7 +273,7 @@ class Completions:
                         final_chunk=None,
                         content=""
                     )
-                return maitai_completion
+                return MaitaiCompletion(maitai_completion)
 
 
 def _process_openai_stream(session_id: Union[str, int],
@@ -284,7 +284,7 @@ def _process_openai_stream(session_id: Union[str, int],
                            stream: openai.Stream[openai_chat_types.ChatCompletionChunk],
                            evaluation_enabled: bool,
                            chat_completion_params: ChatCompletionParams,
-                           callback: Optional[EvaluateCallback] = None, ) -> Iterable[ChatCompletionChunk]:
+                           callback: Optional[EvaluateCallback] = None, ) -> Iterable[MaitaiChunk]:
     full_body = ""
     proto_messages = openai_messages_to_proto(messages)
     last_chunk = None
@@ -297,7 +297,7 @@ def _process_openai_stream(session_id: Union[str, int],
                 full_body += content
         if maitai_chunk.usage and last_chunk is not None and not last_chunk.usage:
             last_chunk.usage = maitai_chunk.usage
-        yield maitai_chunk
+        yield MaitaiChunk(maitai_chunk)
     if evaluation_enabled:
         proto_messages.append(ChatMessage(role="assistant", content=full_body))
         Evaluator.evaluate(
@@ -324,7 +324,7 @@ def _process_openai_stream(session_id: Union[str, int],
         )
 
 
-def _process_inference_stream(stream: Iterable[InferenceStreamResponse]) -> Iterable[ChatCompletionChunk]:
+def _process_inference_stream(stream: Iterable[InferenceStreamResponse]) -> Iterable[MaitaiChunk]:
     for infer_resp in stream:
         if infer_resp.warning:
             warnings.warn(infer_resp.warning, InferenceWarning)
@@ -332,6 +332,7 @@ def _process_inference_stream(stream: Iterable[InferenceStreamResponse]) -> Iter
             raise InferenceException(infer_resp.error)
         chunk = infer_resp.chat_completion_chunk
         if chunk is not None:
-            yield chunk
+            print(chunk)
+            yield MaitaiChunk(chunk)
             if chunk.choices and chunk.choices[0].finish_reason:
                 return
