@@ -1,5 +1,4 @@
 import asyncio
-import os
 import threading
 
 from maitai._config import config
@@ -7,7 +6,6 @@ from maitai_gen.chat import ChatCompletionParams, ChatCompletionRequest
 
 
 class MaitaiClient:
-    MAITAI_HOST = os.environ.get("MAITAI_HOST", 'https://api.trymaitai.ai')
 
     def __init__(self):
         super().__init__()
@@ -37,15 +35,19 @@ class MaitaiClient:
             threading.Thread(target=run).start()
 
     @classmethod
-    def create_inference_request(cls, application_ref_name, session_id, reference_id, action_type, apply_corrections, evaluation_enabled, completion_params: ChatCompletionParams, callback):
+    def create_inference_request(cls, application_ref_name, session_id, reference_id, intent, apply_corrections, evaluation_enabled, completion_params: ChatCompletionParams, callback=None, context_retrieval_enabled=False, context_query=None, return_request=False, fallback_model=None):
         infer_request: ChatCompletionRequest = ChatCompletionRequest()
         infer_request.application_ref_name = application_ref_name
         infer_request.reference_id = reference_id
         infer_request.session_id = session_id
-        infer_request.action_type = action_type
+        infer_request.action_type = intent
         infer_request.apply_corrections = apply_corrections
         infer_request.params = completion_params
         infer_request.evaluation_enabled = evaluation_enabled
         infer_request.auth_keys = config.auth_keys
         infer_request.return_evaluation = True if callback else False
+        infer_request.context_retrieval_enabled = context_retrieval_enabled
+        infer_request.context_query = context_query
+        infer_request.return_request = return_request
+        infer_request.fallback_model = fallback_model
         return infer_request
